runner

package
v0.0.0-...-36d6306 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 5, 2026 License: Apache-2.0 Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunFlow

func RunFlow(ctx context.Context, flowPtr *mflow.Flow, services RunnerServices, reporters *reporter.ReporterGroup) (model.FlowRunResult, error)

func RunMultipleFlows

func RunMultipleFlows(ctx context.Context, fileData []byte, allFlows []mflow.Flow, services RunnerServices, logger *slog.Logger, reporters *reporter.ReporterGroup) error

RunMultipleFlows executes multiple flows based on the run field configuration

Types

type JSRunner

type JSRunner struct {
	// contains filtered or unexported fields
}

JSRunner manages the lifecycle of the Node.js worker process

func NewJSRunner

func NewJSRunner() (*JSRunner, error)

NewJSRunner checks if Node.js is available and returns a runner instance

func (*JSRunner) Client

Client returns the RPC client for the JS executor

func (*JSRunner) Start

func (r *JSRunner) Start(ctx context.Context) error

Start starts the JS worker process and waits for it to be healthy

func (*JSRunner) Stop

func (r *JSRunner) Stop()

Stop stops the JS worker process and cleans up

type RunnerServices

type RunnerServices struct {
	NodeService         sflow.NodeService
	EdgeService         sflow.EdgeService
	FlowVariableService sflow.FlowVariableService
	Builder             *flowbuilder.Builder
	JSClient            node_js_executorv1connect.NodeJsExecutorServiceClient
}

Jump to