renv

package
v0.0.0-...-36d6306 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 5, 2026 License: Apache-2.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckOwnerEnv

func CheckOwnerEnv(ctx context.Context, su suser.UserService, es senv.EnvService, envid idwrap.IDWrap) (bool, error)

Helper function to check environment ownership

func CheckOwnerVar

func CheckOwnerVar(ctx context.Context, su suser.UserService, vs senv.VariableService, es senv.EnvService, varID idwrap.IDWrap) (bool, error)

Helper function to check environment variable ownership

func CreateService

func CreateService(srv EnvRPC, options []connect.HandlerOption) (*api.Service, error)

Types

type EnvRPC

type EnvRPC struct {
	DB *sql.DB
	// contains filtered or unexported fields
}

func New

func New(deps EnvRPCDeps) EnvRPC

func (*EnvRPC) EnvironmentCollection

EnvironmentCollection returns all environments the user has access to

func (*EnvRPC) EnvironmentDelete

EnvironmentDelete deletes an environment

func (*EnvRPC) EnvironmentInsert

EnvironmentInsert creates a new environment

func (*EnvRPC) EnvironmentSync

EnvironmentSync handles real-time synchronization for environments

func (*EnvRPC) EnvironmentUpdate

EnvironmentUpdate updates an existing environment

func (*EnvRPC) EnvironmentVariableCollection

EnvironmentVariableCollection returns all environment variables for environments the user has access to

func (*EnvRPC) EnvironmentVariableDelete

EnvironmentVariableDelete deletes environment variables

func (*EnvRPC) EnvironmentVariableInsert

EnvironmentVariableInsert creates new environment variables

func (*EnvRPC) EnvironmentVariableSync

EnvironmentVariableSync handles real-time synchronization for environment variables

func (*EnvRPC) EnvironmentVariableUpdate

EnvironmentVariableUpdate updates existing environment variables

type EnvRPCDeps

type EnvRPCDeps struct {
	DB        *sql.DB
	Services  EnvRPCServices
	Readers   EnvRPCReaders
	Streamers EnvRPCStreamers
	Publisher mutation.Publisher // Unified publisher for cascade delete events
}

func (*EnvRPCDeps) Validate

func (d *EnvRPCDeps) Validate() error

type EnvRPCReaders

type EnvRPCReaders struct {
	Env      *senv.EnvReader
	Variable *senv.VariableReader
}

func (*EnvRPCReaders) Validate

func (r *EnvRPCReaders) Validate() error

type EnvRPCServices

type EnvRPCServices struct {
	Env       senv.EnvService
	Variable  senv.VariableService
	User      suser.UserService
	Workspace sworkspace.WorkspaceService
}

func (*EnvRPCServices) Validate

func (s *EnvRPCServices) Validate() error

type EnvironmentEvent

type EnvironmentEvent struct {
	Type        string
	Environment *apiv1.Environment
}

type EnvironmentTopic

type EnvironmentTopic struct {
	WorkspaceID idwrap.IDWrap
}

type EnvironmentVariableEvent

type EnvironmentVariableEvent struct {
	Type     string
	Variable *apiv1.EnvironmentVariable
}

type EnvironmentVariableTopic

type EnvironmentVariableTopic struct {
	WorkspaceID   idwrap.IDWrap
	EnvironmentID idwrap.IDWrap
}

Jump to