package
Version:
v0.0.0-...-36d6306
Opens a new window with list of versions in this module.
Published: Jul 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetAllWithState[E Enabled](enables *[]E, state bool)
just get enabled etc...
type Enabled interface {
IsEnabled() bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.